import { EngineMap } from './engine-map.js';
import { Markdown } from './engines/markdown.js';
import { Handlebars } from './engines/handlebars.js';
import { EJS } from './engines/ejs.js';
import { Pug } from './engines/pug.js';
import { Nunjucks } from './engines/nunjucks.js';
import { Liquid } from './engines/liquid.js';
import type { EngineInterface } from './engine-interface.js';
export declare class Ecto {
    private readonly __mapping;
    private readonly __engines;
    private __defaultEngine;
    private readonly __ejs;
    private readonly __markdown;
    private readonly __pug;
    private readonly __nunjucks;
    private readonly __handlebars;
    private readonly __liquid;
    constructor(options?: Record<string, unknown>);
    get defaultEngine(): string;
    set defaultEngine(value: string);
    get mappings(): EngineMap;
    get ejs(): EJS;
    get markdown(): Markdown;
    get pug(): Pug;
    get nunjucks(): Nunjucks;
    get handlebars(): Handlebars;
    get liquid(): Liquid;
    render(source: string, data?: Record<string, unknown>, engineName?: string, rootTemplatePath?: string, filePathOutput?: string): Promise<string>;
    renderSync(source: string, data?: Record<string, unknown>, engineName?: string, rootTemplatePath?: string, filePathOutput?: string): string;
    renderFromFile(filePath: string, data?: Record<string, unknown>, rootTemplatePath?: string, filePathOutput?: string, engineName?: string): Promise<string>;
    renderFromFileSync(filePath: string, data?: Record<string, unknown>, rootTemplatePath?: string, filePathOutput?: string, engineName?: string): string;
    ensureFilePath(path: string): Promise<void>;
    ensureFilePathSync(path: string): void;
    getEngineByFilePath(filePath: string): string;
    findTemplateWithoutExtension(path: string, templateName: string): Promise<string>;
    findTemplateWithoutExtensionSync(path: string, templateName: string): string;
    isValidEngine(engineName?: string): boolean;
    registerEngineMappings(): void;
    getRenderEngine(engineName: string): EngineInterface;
    private writeFile;
    private writeFileSync;
}
